@@ -1,6 +1,6 @@
 #!/usr/bin/env python3
 # --------------------( LICENSE                            )--------------------
-# Copyright (c) 2014-2024 Beartype authors.
+# Copyright (c) 2014-2025 Beartype authors.
 # See "LICENSE" for further details.
 
 '''
@@ -46,9 +46,10 @@ import typing as _typing
 from beartype.roar import BeartypeCallUnavailableTypeException
 from beartype._cave._caveabc import BoolType
 from beartype._util.py.utilpyversion import (
+    IS_PYTHON_AT_LEAST_3_14,
     IS_PYTHON_AT_LEAST_3_12,
+    IS_PYTHON_AT_LEAST_3_11,
     IS_PYTHON_AT_LEAST_3_10,
-    IS_PYTHON_AT_LEAST_3_9,
 )
 from collections import deque as _deque
 from collections.abc import (
@@ -174,6 +175,21 @@ either as C extensions or in pure Python).
 '''
 
 # ....................{ TYPES ~ core : singleton           }....................
+#FIXME: Uncomment this after dropping Python 3.9. Pyright hates this under
+#Python 3.9. *sigh*
+# # If this submodule is currently being statically type-checked by a pure static
+# # type-checker, ignore false positives complaining that these types are not
+# # types.
+# if TYPE_CHECKING:
+#     from types import (  # type: ignore[attr-defined]
+#         EllipsisType as EllipsisType,  # pyright: ignore
+#         NoneType as NoneType,  # pyright: ignore
+#         NotImplementedType as NotImplementedType,  # pyright: ignore
+#     )
+# # Else, this submodule is *NOT* currently being statically type-checked by a
+# # pure static type-checker. In this case, define these types properly. *sigh*
+#else:
+
 EllipsisType: type = type(Ellipsis)
 '''
 Type of the :data:`Ellipsis` singleton.
@@ -184,10 +200,10 @@ NoneType: type = type(None)
 '''
 Type of the :data:`None` singleton.
 
-Curiously, although the type of the :data:`None` object is a class object whose
-``__name__`` attribute is ``NoneType``, there exists no globally accessible
-class by that name. To circumvents this obvious oversight, this global globally
-exposes this class.
+Curiously, although the type of the :data:`None` object is a class object
+whose ``__name__`` attribute is ``"NoneType"``, there exists no globally
+accessible class by that name. To circumvents this obvious oversight, this
+global globally exposes this class.
 
 This class is principally useful for annotating both:
 
@@ -195,32 +211,19 @@ This class is principally useful for annotating both:
 * Callables returning :data:`None` as a valid value.
 
 Note that, for obscure and uninteresting reasons, the standard :mod:`types`
-module defined the same type with the same name under Python 2.x but *not* 3.x.
-Depressingly, this type must now be manually redefined everywhere.
+module defined the same type with the same name under Python 2.x but *not*
+3.x. Depressingly, this type must now be manually redefined everywhere.
 '''
 
 
-NotImplementedType: type = type(NotImplemented)  # type: ignore[misc]
+# Define this type as either...
+NotImplementedType: type = type(NotImplemented)
 '''
 Type of the :data:`NotImplemented` singleton.
 '''
 
 # ....................{ TYPES ~ call                       }....................
-CallablePartialType = _functools.partial
-'''
-Type of all **pure-Python partial callables** (i.e., callables dynamically
-wrapped by the function-like :class:`functools.partial` class, implemented in
-pure Python).
-
-Caveats
-----------
-This type does *not* distinguish between whether the original callable wrapped
-by :class:`functools.partial` is C-based or pure Python -- only that some
-callable of indeterminate origin is in fact wrapped.
-'''
-
-
-CallableCodeObjectType: Any = type((lambda: None).__code__)
+CallableCodeObjectType = _types.CodeType
 '''
 Type of all **code objects** (i.e., C-based objects underlying all pure-Python
 callables to which those callables are compiled for efficiency).
@@ -281,7 +284,7 @@ interpreters,** including:
 
 See Also
 --------
-:class:`MethodBoundInstanceOrClassType`
+:class:`.MethodBoundInstanceOrClassType`
     Type of all pure-Python bound instance and class methods.
 '''
 
@@ -305,7 +308,7 @@ Caveats
 -------
 There exists *no* corresponding :class:`MethodUnboundInstanceType` type, as
 unbound pure-Python instance methods are ambiguously implemented as functions of
-type :class:`FunctionType` indistinguishable from conventional functions.
+type :class:`.FunctionType` indistinguishable from conventional functions.
 Indeed, `official documentation <PyInstanceMethod_Type documentation_>`__ for
 the ``PyInstanceMethod_Type`` C type explicitly admits that:
 
@@ -317,6 +320,7 @@ the ``PyInstanceMethod_Type`` C type explicitly admits that:
 '''
 
 
+#FIXME: Directly alias this to "_types.MethodWrapperType" now, please.
 # Although Python >= 3.7 now exposes an explicit method wrapper type via the
 # standard "types.MethodWrapperType" object, this is of no benefit to older
 # versions of Python. Ergo, the type of an arbitrary method wrapper guaranteed
@@ -438,8 +442,9 @@ MethodDecoratorPropertyType = property
 '''
 Type of all **C-based unbound property method descriptors** (i.e., non-callable
 instances of the builtin :class:`property` decorator class implemented in
-low-level C, associated with property getter and setter methods implemented in
-pure Python, and accessed as class rather than instance attributes).
+low-level C, associated with property getter, setter, and deleter methods
+implemented in pure-Python, and accessed as class rather than instance
+attributes).
 
 Caveats
 -------
@@ -465,7 +470,7 @@ Caveats
 Static method objects are *only* directly accessible via the low-level
 :attr:`object.__dict__` dictionary. When accessed as class or instance
 attributes, static methods reduce to instances of the standard
-:class:`FunctionType` type.
+:class:`.FunctionType` type.
 
 Static method objects are *not* callable, as their implementations fail to
 define the ``__call__`` dunder method.
@@ -549,15 +554,73 @@ implementing the :class:`collections.abc.Iterator` protocol, the former only
 applies to generators implicitly created by Python itself.
 '''
 
-# ....................{ TYPES ~ class                      }....................
-ClassDictType = type(type.__dict__)
+# ....................{ TYPES ~ call : module : functools  }....................
+CallableFunctoolsPartialType = _functools.partial
 '''
-Type of all **pure-Python class dictionaries** (i.e., immutable mappings
-officially referred to as "mapping proxies," whose keys are strictly constrained
-for both efficiency and correctness to be Python identifier strings).
+Pure-Python type of all **partial callables** (i.e., possibly C-based callable
+wrapped by the pure-Python callable :class:`functools.partial` type).
+
+Caveats
+-------
+This type does *not* distinguish between whether the original callable wrapped
+by :class:`functools.partial` is C-based or pure Python -- only that some
+callable of indeterminate origin is in fact wrapped.
 '''
 
-# ....................{ TYPES ~ data                       }....................
+
+@_functools.lru_cache
+def _lru_cache_func(n: int) -> int:
+    '''
+    Arbitrary :func:`functools.lru_cache`-memoized function defined solely to
+    inspect various dunder attributes common to all such functions.
+    '''
+
+    return n + 1
+
+
+# If this submodule is currently being statically type-checked by a pure static
+# type-checker, ignore false positives complaining that this type is not a type.
+if TYPE_CHECKING:
+    class CallableFunctoolsLruCacheType(object): pass
+# Else, this submodule is *NOT* currently being statically type-checked by a
+# pure static type-checker. In this case, define this type properly. *sigh*
+else:
+    CallableFunctoolsLruCacheType = type(_lru_cache_func)
+    '''
+    C-based type of all low-level private objects created and returned by the
+    :func:`functools.lru_cache` decorator (e.g.,
+    :class:`functools._lru_cache_wrapper`).
+
+    This type enables functionality elsewhere to reliably detect when a callable
+    has been decorated by that decorator.
+    '''
+# print(f'LRU_CACHE_TYPE: {LRU_CACHE_TYPE}')
+
+
+# Delete temporary private callables defined above as a negligible safety (and
+# possible space complexity) measure.
+del _lru_cache_func
+
+# ....................{ TYPES ~ class                      }....................
+# If this submodule is currently being statically type-checked by a pure static
+# type-checker, ignore false positives complaining that this type is not a type.
+if TYPE_CHECKING:
+    class ClassDictType(object): pass
+# Else, this submodule is *NOT* currently being statically type-checked by a
+# pure static type-checker. In this case, define this type properly. *sigh*
+else:
+    ClassDictType = type(type.__dict__)
+    '''
+    Type of all **pure-Python class dictionaries** (i.e., immutable mappings
+    officially referred to as "mapping proxies," whose keys are strictly
+    constrained for both efficiency and correctness to be Python identifier
+    strings).
+    '''
+
+# ....................{ TYPES ~ container : abc            }....................
+#FIXME: Extremely silly, honestly. Just use "collections.abc" directly. This is
+#an obvious facepalm. We sigh. *sigh*
+
 ContainerType = _Container
 '''
 Type of all **containers** (i.e., concrete instances of the abstract
@@ -713,7 +776,7 @@ See Also
     Further details on structural subtyping.
 '''
 
-# ....................{ TYPES ~ data : mapping             }....................
+# ....................{ TYPES ~ container : abc : mapping  }....................
 HashableType = _Hashable
 '''
 Type of all **hashable objects** (i.e., both concrete and structural instances
@@ -848,6 +911,35 @@ See Also
     Further details on sequences.
 '''
 
+# ....................{ TYPES ~ container : dict           }....................
+# Temporary dictionary to be deleted below.
+_dict: dict = {}
+
+
+DictItemsViewType: type = type(_dict.items())
+'''
+Type of all **dictionary items views** (i.e., objects created and returned by
+the :meth:`dict.items` method).
+'''
+
+
+DictKeysViewType: type = type(_dict.keys())
+'''
+Type of all **dictionary keys views** (i.e., objects created and returned by the
+:meth:`dict.keys` method).
+'''
+
+
+DictValuesViewType: type = type(_dict.values())
+'''
+Type of all **dictionary values views** (i.e., objects created and returned by
+the :meth:`dict.values` method).
+'''
+
+
+# Delete the dictionary defined above for negligible space gains.
+del _dict
+
 # ....................{ TYPES ~ enum                       }....................
 # Enumeration types are sufficiently obscure to warrant formalization here.
 
@@ -916,52 +1008,56 @@ that enumeration's type and should be directly referenced as such: e.g.,
 '''
 
 # ....................{ TYPES ~ hint : pep : 585           }....................
-# Define this type as either...
-HintGenericSubscriptedType: type = (
-    # If the active Python interpreter targets at least Python >= 3.9 and thus
-    # supports PEP 585, this type;
-    type(list[str])  # type: ignore[misc]
-    if IS_PYTHON_AT_LEAST_3_9 else
-    # Else, a placeholder type.
-    UnavailableType
-)
-'''
-C-based type of all subscripted generics if the active Python interpreter
-targets Python >= 3.9 *or* :class:`.UnavailableType` otherwise.
+# If this submodule is currently being statically type-checked by a pure static
+# type-checker, ignore false positives complaining that this type is not a type.
+# Notably, mypy inexplicably refuses to accept this by emitting "errors"
+# resembling the following wherever this type is accessed:
+#     beartype._util.hint.pep.proposal.pep695.py:120: error: Variable "beartype._cave._cavefast.HintPep695TypeAlias" is not valid as a type [valid-type]
+#     beartype._util.hint.pep.proposal.pep695.py:120: note: See https://mypy.readthedocs.io/en/stable/common_issues.html#variables-vs-type-aliases
+if TYPE_CHECKING:
+    class HintGenericSubscriptedType(object): pass
+# Else, this submodule is *NOT* currently being statically type-checked by a
+# pure static type-checker. In this case, define this type properly. *sigh*
+else:
+    HintGenericSubscriptedType: type = type(list[str])  # type: ignore[misc]
+    '''
+    C-based type of all subscripted generics.
 
-This type is a version-agnostic generalization of the standard
-:class:`types.GenericAlias` type available only under Python >= 3.9. Subscripted
-generics include:
+    This type is a version-agnostic generalization of the standard
+    :class:`types.GenericAlias` type. Subscripted generics include:
 
-* :pep:`585`-compliant **builtin type hints** (i.e., C-based type hints
-  instantiated by subscripting either a concrete builtin container class like
-  :class:`list` or :class:`tuple` *or* an abstract base class (ABC) declared by
-  the :mod:`collections.abc` submodule like :class:`collections.abc.Iterable`
-  or :class:`collections.abc.Sequence`).
-* :pep:`484`-compliant **subscripted generics** (i.e., user-defined classes
-  subclassing one or more :pep:`484`-compliant type hints subsequently
-  subscripted by one or more PEP-compliant type hints).
-* :pep:`585`-compliant **subscripted generics** (i.e., user-defined classes
-  subclassing one or more :pep:`585`-compliant type hints subsequently
-  subscripted by one or more PEP-compliant type hints).
+    * :pep:`585`-compliant **builtin type hints** (i.e., C-based type hints
+      instantiated by subscripting either a concrete builtin container class
+      like :class:`list` or :class:`tuple` *or* an abstract base class (ABC)
+      declared by the :mod:`collections.abc` submodule like
+      :class:`collections.abc.Iterable` or :class:`collections.abc.Sequence`).
+    * :pep:`484`-compliant **subscripted generics** (i.e., user-defined classes
+      subclassing one or more :pep:`484`-compliant type hints subsequently
+      subscripted by one or more PEP-compliant type hints).
+    * :pep:`585`-compliant **subscripted generics** (i.e., user-defined classes
+      subclassing one or more :pep:`585`-compliant type hints subsequently
+      subscripted by one or more PEP-compliant type hints).
 
-Caveats
-----------
-**This low-level type ambiguously matches semantically unrelated PEP-compliant
-type hints,** rendering this type all but useless for most practical purposes.
-To distinguish between the various semantic types of hints ambiguously matched
-by this type, higher-level PEP-specific functions *must* be called instead.
-These include:
+    Caveats
+    -------
+    **This low-level type ambiguously matches semantically unrelated
+    PEP-compliant type hints,** rendering this type all but useless for most
+    practical purposes. To distinguish between the various semantic types of
+    hints ambiguously matched by this type, higher-level PEP-specific functions
+    *must* be called instead. These include:
 
-* :func:`beartype._util.hint.pep.proposal.pep484.utilpep484.is_hint_pep484_generic`,
-  detecting :pep:`484`-compliant generic type hints.
-* :func:`beartype._util.hint.pep.proposal.utilpep585.is_hint_pep585_builtin_subscripted`,
-  detecting :pep:`585`-compliant builtin type hints.
-* :func:`beartype._util.hint.pep.proposal.utilpep585.is_hint_pep585_generic`,
-  detecting :pep:`585`-compliant generic type hints.
-'''
+    * :func:`beartype._util.hint.pep.proposal.pep484.pep484.is_hint_pep484_generic`,
+      detecting :pep:`484`-compliant generic type hints.
+    * :func:`beartype._util.hint.pep.proposal.pep585.is_hint_pep585_builtin_subbed`,
+      detecting :pep:`585`-compliant builtin type hints.
+    * :func:`beartype._util.hint.pep.proposal.pep585.is_hint_pep585_generic`,
+      detecting :pep:`585`-compliant generic type hints.
+    '''
 
 # ....................{ TYPES ~ hint : pep : 604           }....................
+#FIXME: Excise the obsolete "HintPep604Type" type *AFTER* dropping Python 3.13
+#support, please. Under Python >= 3.14, this type is a trivial alias of the
+#standard "typing.Union" type.
 # If this submodule is currently being statically type-checked by a pure static
 # type-checker, ignore false positives complaining that this type is not a type.
 if TYPE_CHECKING:
@@ -989,7 +1085,8 @@ else:
     '''
 
 
-HintPep604Types: _TupleTyping[type, ...] = (type, HintGenericSubscriptedType)
+HintPep604ItemTypes: _TupleTyping[type, ...] = (
+    type, HintGenericSubscriptedType)
 '''
 Tuple of all :pep:`604`-compliant **new union item types** (i.e., types of all
 objects permissible as the items of new unions), including:
@@ -1000,23 +1097,194 @@ objects permissible as the items of new unions), including:
   in the new union ``list[dict[str, int]] | None``).
 '''
 
+# ....................{ TYPES ~ hint : pep : 612           }....................
+# If this submodule is currently being statically type-checked by a pure static
+# type-checker, ignore false positives complaining that these types are not
+# types.
+if TYPE_CHECKING:
+    class HintPep612ParamSpecType(object): pass
+    class HintPep612ParamSpecArgType(object): pass
+    class HintPep612ParamSpecKwargType(object): pass
+# Else, this submodule is *NOT* currently being statically type-checked by a
+# pure static type-checker.
+#
+# If the active Python interpreter targets at least Python >= 3.10 and thus
+# supports PEP 612, define these types properly. *sigh*
+elif IS_PYTHON_AT_LEAST_3_10:
+    HintPep612ParamSpecType = _typing.ParamSpec
+    '''
+    C-based type of all :pep:`612`-compliant **parameter specifications** (i.e.,
+    low-level C-based :obj:`typing.ParamSpec` objects) if the active Python
+    interpreter targets Python >= 3.10 *or* :class:`.UnavailableType` otherwise.
+
+    This type is a version-agnostic generalization of the standard
+    :class:`typing.ParamSpec` type available only under Python >= 3.10.
+    '''
+
+
+    HintPep612ParamSpecArgType = _typing.ParamSpecArgs
+    '''
+    C-based type of all :pep:`612`-compliant **parameter specification variadic
+    positional parameter instance variables** (i.e., low-level C-based
+    :obj:`typing.ParamSpecArgs` objects annotating variadic positional
+    parameters with syntax resembling ``*args: P.args`` for ``P`` a low-level
+    C-based :obj:`typing.ParamSpec` parent object) if the active Python
+    interpreter targets Python >= 3.10 *or* :class:`.UnavailableType` otherwise.
+
+    This type is a version-agnostic generalization of the standard
+    :class:`typing.ParamSpecArgs` type available only under Python >= 3.10.
+    '''
+
+
+    HintPep612ParamSpecKwargType = _typing.ParamSpecKwargs
+    '''
+    C-based type of all :pep:`612`-compliant **parameter specification variadic
+    keyword parameter instance variables** (i.e., low-level C-based
+    :obj:`typing.ParamSpecArgs` objects annotating variadic keyword
+    parameters with syntax resembling ``**kwargs: P.kwargs`` for ``P`` a
+    low-level C-based :obj:`typing.ParamSpec` parent object) if the active
+    Python interpreter targets Python >= 3.10 *or* :class:`.UnavailableType`
+    otherwise.
+
+    This type is a version-agnostic generalization of the standard
+    :class:`typing.ParamSpecKwargs` type available only under Python >= 3.10.
+    '''
+# Else, the active Python interpreter targets Python < 3.10 and thus fails to
+# support PEP 612. In this case, define these types as placeholders. *sigh*
+else:
+    HintPep612ParamSpecType = \
+    HintPep612ParamSpecArgType = \
+    HintPep612ParamSpecKwargType = \
+        UnavailableType
+
+
+HintPep612ParamSpecVarTypes: _TupleTyping[type, ...] = (
+    HintPep612ParamSpecArgType, HintPep612ParamSpecKwargType,)
+'''
+Tuple of all :pep:`612`-compliant **parameter specification variadic parameter
+instance variables** (i.e., low-level C-based :obj:`typing.ParamSpecArgs`
+objects annotating variadic parameters with syntax resembling
+``*args: P.args`` and ``**kwargs: P.kwargs`` for ``P`` a low-level C-based
+:obj:`typing.ParamSpec` parent object).
+'''
+
+# ....................{ TYPES ~ hint : pep : 646           }....................
+#FIXME: Define a new "HintPep646TypeVarTupleUnpackedType", please. It turns out
+#that Python provides a private type that suffices here under Python >= 3.11:
+#    HintPep646TypeVarTupleUnpackedType = _typing._UnpackGenericAlias
+
+# If this submodule is currently being statically type-checked by a pure static
+# type-checker, ignore false positives complaining that these types are not
+# types.
+if TYPE_CHECKING:
+    class HintPep646TypeVarTupleType(object): pass
+    class HintPep646692UnpackedType(object): pass
+# Else, this submodule is *NOT* currently being statically type-checked by a
+# pure static type-checker.
+#
+# If the active Python interpreter targets at least Python >= 3.11 and thus
+# supports PEP 646, define these types properly. *sigh*
+elif IS_PYTHON_AT_LEAST_3_11:
+    HintPep646TypeVarTupleType = _typing.TypeVarTuple
+    '''
+    C-based type of all :pep:`646`-compliant **type variable tuples** (i.e.,
+    low-level C-based :obj:`typing.TypeVarTuple` objects) if the active Python
+    interpreter targets Python >= 3.11 *or* :class:`.UnavailableType` otherwise.
+
+    This type is a version-agnostic generalization of the standard
+    :class:`typing.TypeVarTuple` type available only under Python >= 3.11.
+    '''
+
+
+    HintPep646692UnpackedType = type(
+        _typing.Unpack[HintPep646TypeVarTupleType('Ts')])
+    '''
+    Pure-Python type of all :pep:`646`- and :pep:`692`-compliant **unpacked
+    type hints** (i.e., parent hints expanding the single child hints
+    subscripting these parent hints into the zero or more child child hints
+    subscripting those single child hints), including:
+
+    * :pep:`646`-compliant unpacked type variable tuples.
+    * :pep:`692`-compliant unpacked typed dictionaries.
+
+    This type is equivalent to the currently private
+    :class:`_typing._UnpackGenericAlias` class. For safety, we intentionally
+    avoid violating privacy encapsulation by referring to this type directly.
+
+    Caveats
+    -------
+    **This type is ambiguous and thus invites false negatives and positives.**
+    There exist no finer-grained types unambiguously unique to either
+    :pep:`646`-compliant unpacked type variable tuples *or* :pep:`692`-compliant
+    unpacked typed dictionaries. This type is the finest-grained type available.
+    Differentiating between the various kinds of unpacked hints requires calling
+    various utility functions implementing additional runtime heuristics.
+    '''
+# Else, the active Python interpreter targets Python < 3.11 and thus fails to
+# support PEP 646. In this case, define these types as placeholders. *sigh*
+else:
+    HintPep646TypeVarTupleType = UnavailableType
+    HintPep646692UnpackedType = UnavailableType
+
+
+HintPep484612646TypeArgPackedTypes = (
+    _typing.TypeVar, HintPep612ParamSpecType, HintPep646TypeVarTupleType)
+'''
+Tuple of all **packed type parameters types** (i.e., types of
+:pep:`484`-compliant type variables, pep:`612`-compliant parameter
+specifications, and :pep:`646`-compliant type variable tuples).
+'''
+
+# ....................{ TYPES ~ hint : pep : 649           }....................
+#FIXME: After dropping Python 3.13 support, globally replace:
+#    # All imports like this...
+#    from beartype._cave._cavefast import Format
+#
+#    # ...with imports like this! \o/
+#    from annotationlib import Format
+#
+#Then remove *ALL* of the PEP 649-specific logic below.
+
+# If either...
+if (
+    # This submodule is currently being statically type-checked by a pure static
+    # type-checker *OR*...
+    TYPE_CHECKING or
+    # The active Python interpreter targets Python >= 3.14...
+    IS_PYTHON_AT_LEAST_3_14
+):
+    # Import the standard PEP 649-compliant "annotationlib.Format" enum defined
+    # *ONLY* under Python >= 3.14.
+    from annotationlib import Format as Format  # type: ignore[import-not-found]
+# Else, this submodule is currently being imported at runtime under an active
+# Python interpreter targets that targets at most Python <= 3.13 and thus
+# fails to define the standard PEP 649-compliant "annotationlib.Format" enum. In
+# this case, define a placeholder enum declaring the same members.
+else:
+    import enum
+
+    # For simplicity, copy-paste the *EXACT SAME* definition of this enum as
+    # appears at the head of the standard "annotationlib" module.
+    class Format(enum.IntEnum):
+        VALUE = 1
+        VALUE_WITH_FAKE_GLOBALS = 2
+        FORWARDREF = 3
+        STRING = 4
+
 # ....................{ TYPES ~ hint : pep : 695           }....................
 # If this submodule is currently being statically type-checked by a pure static
 # type-checker, ignore false positives complaining that this type is not a type.
 # Notably, mypy inexplicably refuses to accept this by emitting "errors"
 # resembling the following wherever this type is accessed:
-#     beartype/_util/hint/pep/proposal/utilpep695.py:120: error: Variable
-#         "beartype._cave._cavefast.HintPep695Type" is not valid as a type
-#         [valid-type]
-#     beartype/_util/hint/pep/proposal/utilpep695.py:120: note: See
-#         https://mypy.readthedocs.io/en/stable/common_issues.html#variables-vs-type-aliases
+#     beartype._util.hint.pep.proposal.pep695.py:120: error: Variable "beartype._cave._cavefast.HintPep695TypeAlias" is not valid as a type [valid-type]
+#     beartype._util.hint.pep.proposal.pep695.py:120: note: See https://mypy.readthedocs.io/en/stable/common_issues.html#variables-vs-type-aliases
 if TYPE_CHECKING:
-    class HintPep695Type(object): pass
+    class HintPep695TypeAlias(object): pass
 # Else, this submodule is *NOT* currently being statically type-checked by a
 # pure static type-checker. In this case, define this type properly. *sigh*
 else:
     # Define this type as either...
-    HintPep695Type = (
+    HintPep695TypeAlias = (
         # If the active Python interpreter targets at least Python >= 3.12 and
         # thus supports PEP 695, this type;
         _typing.TypeAliasType
@@ -1034,6 +1302,21 @@ else:
     :class:`typing.TypeAliasType` type available only under Python >= 3.12.
     '''
 
+
+Pep695ParameterizableTypes = (type, FunctionType, HintPep695TypeAlias)
+'''
+Tuple of all :pep:`695`-compliant **parameterizable types** (i.e., types of
+objects that may be parametrized by :pep:`695`-compliant lists of one or more
+implicitly instantiated :pep:`484`-compliant type variables, pep:`612`-compliant
+parameter specifications, or :pep:`646`-compliant type variable tuples).
+
+Specifically, this tuple matches:
+
+* *Any* pure-Python class.
+* *Any* pure-Python function.
+* *Any* :pep:`695`-compliant type alias.
+'''
+
 # ....................{ TYPES ~ scalar                     }....................
 StrType = str    # Well, isn't that special.
 '''
@@ -1051,7 +1334,7 @@ This type matches:
   builtin Unicode strings are usable.
 
 Caveats
-----------
+-------
 This type does *not* match **encoded byte strings** (i.e., sequences of
 physical encoded bytes, including the builtin :class:`bytestring` type), which
 require foreknowledge of the encoding previously used to encode those bytes.
@@ -1251,7 +1534,7 @@ Tuple of all **function types** (i.e., types whose instances are either
 built-in or user-defined functions).
 
 Caveats
-----------
+-------
 **This tuple may yield false positives when used to validate types.** Since
 Python fails to distinguish between C-based functions and methods, this tuple
 is the set of all function types as well as the ambiguous type of all C-based
@@ -1282,36 +1565,59 @@ classes) are *not* callable and thus intentionally excluded.
 '''
 
 
+MethodDecoratorClassOrStaticTypes = (
+    MethodDecoratorClassType,
+    MethodDecoratorStaticType,
+)
+'''
+Tuple of all **C-based unbound class or static method decorator types** (i.e.,
+builtin :class:`classmethod` or :class:`staticmethod` decorator types
+implemented in low-level C whose instances are typically uncallable, associated
+with callable methods implemented in pure Python).
+'''
+
+
 MethodDecoratorBuiltinTypes = (
     MethodDecoratorClassType,
     MethodDecoratorPropertyType,
     MethodDecoratorStaticType,
 )
 '''
-Tuple of all **C-based unbound method decorator types** (i.e., builtin decorator
-types implemented in low-level C whose instances are typically uncallable,
-associated with callable methods implemented in pure Python).
+Tuple of all **builtin unbound method decorator types** (i.e., C-based decorator
+types builtin to Python whose instances are typically uncallable but encapsulate
+callable pure-Python methods).
+'''
+
+
+MethodDescriptorNondataTypes = (
+    MethodDecoratorClassType,
+    MethodDecoratorStaticType,
+    MethodBoundInstanceOrClassType,
+)
+'''
+Tuple of all **builtin method non-data descriptor types** (i.e., C-based
+descriptors builtin to Python defining only the ``__get__()`` dunder method,
+encapsulating read-only access to some kind of method).
 '''
 
 
 MethodDescriptorTypes = (
     # @classmethod, @staticmethod, and @property descriptor types.
-    MethodDecoratorBuiltinTypes + (
-        # Method descriptor type.
-        MethodBoundInstanceOrClassType,
-    )
+    MethodDecoratorBuiltinTypes +
+    # Method descriptor type.
+    (MethodBoundInstanceOrClassType,)
 )
 '''
-Tuple of all **C-based unbound method descriptor types** (i.e., builtin types
-implemented in low-level C whose instances are typically uncallable, associated
-with callable methods implemented in pure Python).
+Tuple of all **builtin method descriptor types** (i.e., C-based descriptors
+builtin to Python, encapsulating various operations on various kinds of methods
+whose instances are typically uncallable).
 
 This tuple matches the types of all:
 
 * **Class method descriptors** (i.e., methods decorated by the builtin
   :class:`classmethod` decorator).
-* Instance method descriptors (i.e., methods *not* decorated by a builtin method
-  decorator).
+* **Instance method descriptors** (i.e., methods *not* decorated by a builtin
+  method decorator).
 * **Property method descriptors** (i.e., methods decorated by the builtin
   :class:`property` decorator).
 * **Static method descriptors** (i.e., methods decorated by the builtin
@@ -1329,7 +1635,7 @@ Unbound decorator objects (e.g., non-callable instances of the builtin
 classes) are *not* callable and thus intentionally excluded.
 
 Caveats
-----------
+-------
 **This tuple may yield false positives when used to validate types.** Since
 Python fails to distinguish between C-based functions and methods, this tuple
 is the set of all pure-Python bound and unbound method types as well as the
@@ -1390,10 +1696,10 @@ Tuple of all callable types as well as the string type.
 '''
 
 
-#FIXME: Define a new "CallableClassType" by copying the "BoolType" approach
+#FIXME: Define a new "ClassCallableType" by copying the "BoolType" approach
 #except for the __call__() dunder method instead.
-#FIXME: Replace "ClassType" below by "CallableClassType".
-#FIXME: Add the "CallableClassType" type to the "CallableTypes" tuple as well.
+#FIXME: Replace "ClassType" below by "ClassCallableType".
+#FIXME: Add the "ClassCallableType" type to the "CallableTypes" tuple as well.
 DecoratorTypes = CallableTypes + (ClassType,)
 '''
 Tuple of all **decorator types** (i.e., both callable classes *and* the type of
@@ -1417,24 +1723,7 @@ callables implemented in pure Python whose declaration is preceded by the
 ``async`` keyword).
 '''
 
-# ....................{ TUPLES ~ scalar                    }....................
-BoolOrNumberTypes = (BoolType, NumberType,)
-'''
-Tuple of all **boolean** and **number types** (i.e., classes whose instances
-are either numbers or types trivially convertible into numbers).
-
-This tuple matches booleans, integers, rational numbers, irrational numbers,
-real numbers, and complex numbers.
-
-Booleans are trivially convertible into integers. While details differ by
-implementation, common implementations in lower-level languages (e.g., C, C++,
-Perl) typically implicitly convert:
-
-* ``False`` to ``0`` and vice versa.
-* ``True`` to ``1`` and vice versa.
-'''
-
-# ....................{ TUPLES ~ post-init : container     }....................
+# ....................{ TUPLES ~ container : abc           }....................
 # Tuples of types assuming the above initialization to have been performed.
 
 MappingOrSequenceTypes = (MappingType, SequenceType)
@@ -1468,7 +1757,24 @@ Tuple of all numeric types *and* all container base classes conforming to (but
 API.
 '''
 
-# ....................{ TUPLES ~ post-init : scalar        }....................
+# ....................{ TUPLES ~ scalar                    }....................
+BoolOrNumberTypes = (BoolType, NumberType,)
+'''
+Tuple of all **boolean** and **number types** (i.e., classes whose instances
+are either numbers or types trivially convertible into numbers).
+
+This tuple matches booleans, integers, rational numbers, irrational numbers,
+real numbers, and complex numbers.
+
+Booleans are trivially convertible into integers. While details differ by
+implementation, common implementations in lower-level languages (e.g., C, C++,
+Perl) typically implicitly convert:
+
+* ``False`` to ``0`` and vice versa.
+* ``True`` to ``1`` and vice versa.
+'''
+
+
 ScalarTypes = BoolOrNumberTypes + (StrType,)
 '''
 Tuple of all **scalar types** (i.e., classes whose instances are atomic scalar
@@ -1481,7 +1787,7 @@ This tuple matches all:
 * **Textual types** (i.e., types contained in the :class:`StrTypes` tuple).
 '''
 
-# ....................{ TUPLES ~ stdlib                    }....................
+
 RegexTypes = (RegexCompiledType, StrType)
 '''
 Tuple of all **regular expression-like types** (i.e., types either defining
