@@ -1,13 +1,11 @@
 #!/usr/bin/env python3
 # --------------------( LICENSE                            )--------------------
-# Copyright (c) 2014-2023 Beartype authors.
+# Copyright (c) 2014-2025 Beartype authors.
 # See "LICENSE" for further details.
 
 '''
-Project-wide **callable creation** utilities.
-
-This private submodule implements utility functions dynamically creating new
-callables on-the-fly.
+Project-wide **callable factories** (i.e., low-level functions dynamically
+creating and returning new in-memory callables).
 
 This private submodule is *not* intended for importation by downstream callers.
 '''
@@ -15,14 +13,16 @@ This private submodule is *not* intended for importation by downstream callers.
 # ....................{ IMPORTS                            }....................
 from beartype.roar._roarexc import _BeartypeUtilCallableException
 from beartype.typing import (
+    Callable,
     Optional,
-    Type,
 )
-from beartype._data.hint.datahinttyping import LexicalScope
+from beartype._data.typing.datatyping import (
+    LexicalScope,
+    TypeException,
+)
 from beartype._util.text.utiltextlabel import label_exception
-from beartype._util.text.utiltextmunge import number_lines
+from beartype._util.text.utiltextmunge import number_str_lines
 from beartype._util.utilobject import get_object_name
-from collections.abc import Callable
 from functools import update_wrapper
 from linecache import cache as linecache_cache  # type: ignore[attr-defined]
 from weakref import finalize
@@ -35,12 +35,13 @@ def make_func(
 
     # Optional arguments.
     func_globals: Optional[LexicalScope] = None,
-    func_locals:  Optional[LexicalScope] = None,
+    func_locals: Optional[LexicalScope] = None,
     func_doc: Optional[str] = None,
-    func_label:   Optional[str] = None,
+    func_label: Optional[str] = None,
+    func_labeller: Optional[Callable[[], str]] = None,
     func_wrapped: Optional[Callable] = None,
     is_debug: bool = False,
-    exception_cls: Type[Exception] = _BeartypeUtilCallableException,
+    exception_cls: TypeException = _BeartypeUtilCallableException,
 ) -> Callable:
     '''
     Dynamically create and return a new function with the passed name declared
@@ -56,36 +57,53 @@ def make_func(
         signature prefixed by zero or more decorations *and* body. **This
         snippet must be unindented.** If this snippet is indented, this factory
         raises a syntax error.
-    func_globals : Dict[str, Any], optional
+    func_globals : dict[str, Any] | None
         Dictionary mapping from the name to value of each **globally scoped
         attribute** (i.e., internally referenced in the body of the function
         declared by this code snippet). Defaults to the empty dictionary.
-    func_locals : Dict[str, Any], optional
+    func_locals : dict[str, Any] | None
         Dictionary mapping from the name to value of each **locally scoped
         attribute** (i.e., internally referenced either in the signature of
         the function declared by this code snippet *or* as decorators
         decorating that function). **Note that this factory necessarily
         modifies the contents of this dictionary.** Defaults to the empty
         dictionary.
-    func_doc : str, optional
+    func_doc : str | None
         Human-readable docstring documenting this function. Defaults to
-        ``None``, in which case this function remains undocumented.
-    func_label : str, optional
+        :data:`None`, in which case this function remains undocumented.
+    func_label : str | None
         Human-readable label describing this function for error-handling
-        purposes. Defaults to ``{func_name}()``.
-    func_wrapped : Callable, optional
-        Callable wrapped by the function to be created. If non-``None``,
+        purposes. Note that this parameter is mutually exclusive with the
+        competing ``func_labeller`` parameter; if both are non-:data:`None`, an
+        exception is raised. Defaults to :data:`None`, in which case this label
+        effectively defaults to ``"{func_name}()"``.
+    func_labeller : Callable[[], str] | None
+        Callback accepting *no* parameters and returning a human-readable label
+        describing this function for error-handling purposes, intended for use
+        cases in which simply passing this label as the ``func_label`` parameter
+        is prohibitively expensive (e.g., due to the cost of string munging).
+        Note that this parameter is mutually exclusive with the competing
+        ``func_label`` parameter; if both are non-:data:`None`, an exception is
+        raised. Defaults to :data:`None`, in which case this label effectively
+        defaults to ``"{func_name}()"``.
+    func_wrapped : Callable | None
+        Callable wrapped by the function to be created. If non-:data:`None`,
         special dunder attributes will be propagated (i.e., copied) from this
         wrapped callable into this created function; these include:
 
-        * ``__name__``, this function's unqualified name.
-        * ``__doc__``, this function's docstring.
-        * ``__module__``, the fully-qualified name of this function's module.
+        * ``__annotate__()``, providing this function's :pep:`649`-compliant
+          annotations factory method.
+        * ``__annotations__``, providing this function's :pep:`649`-compliant
+          annotations dunder dictionary.
+        * ``__name__``, providing this function's unqualified name.
+        * ``__module__``, providing the fully-qualified name of this function's
+          module.
+        * ``__name__``, providing this function's unqualified name.
 
-        Defaults to ``None``.
+        Defaults to :data:`None`.
     is_debug : bool, optional
-        ``True`` only if this function is being debugged. If ``True``, the
-        definition (including signature and body) of this function is:
+        :data:`True` only if this function is being debugged. If :data:`True`,
+        then the definition (including signature and body) of this function is:
 
         * Printed to standard output.
         * Cached with the standard :mod:`linecache` module under a fake
@@ -98,24 +116,25 @@ def make_func(
              from linecache import cache as linecache_cache
              func_source = linecache_cache[func.__code__.co_filename]
 
-        Defaults to ``False``.
-    exception_cls : type, optional
+        Defaults to :data:`False`.
+    exception_cls : Type[Exception], optional
         Type of exception to raise in the event of a fatal error. Defaults to
-        :exc:`_BeartypeUtilCallableException`.
+        :exc:`._BeartypeUtilCallableException`.
 
     Returns
-    ----------
+    -------
     Callable
         Function with this name declared by this snippet.
 
     Raises
-    ----------
-    :exc:`exception_cls`
+    ------
+    exception_cls
         If either:
 
         * ``func_locals`` contains a key whose value is that of ``func_name``,
           implying the caller already declared a local attribute whose name
           collides with that of this function.
+        * ``func_label`` and ``func_labeller`` are both non-:data:`None`.
         * This code snippet is syntactically invalid.
         * This code snippet is syntactically valid but fails to declare a
           function with this name.
@@ -127,26 +146,41 @@ def make_func(
     assert isinstance(is_debug, bool), f'{repr(is_debug)} not bool.'
     assert func_name, 'Parameter "func_name" empty.'
     assert func_code, 'Parameter "func_code" empty.'
+    assert func_label is None or func_labeller is None, (
+        f'Parameters "func_label" and "func_labeller" both non-"None".')
 
     # Default all unpassed parameters.
     if func_globals is None:
         func_globals = {}
     if func_locals is None:
         func_locals = {}
-    if func_label is None:
-        func_label = f'{func_name}()'
     assert isinstance(func_globals, dict), (
         f'{repr(func_globals)} not dictionary.')
     assert isinstance(func_locals, dict), (
         f'{repr(func_locals)} not dictionary.')
-    assert isinstance(func_label, str), f'{repr(func_label)} not string.'
+
+    # If "func_labeller" is unpassed...
+    if func_labeller is None:
+        # If both "func_label" *AND* "func_labeller" are unpassed, default
+        # "func_label" to a sensible label.
+        if func_label is None:
+            func_label = f'{func_name}()'
+        # Else, only "func_labeller" is unpassed.
+        #
+        # In either case, "func_label" should now be a valid label.
+
+        assert isinstance(func_label, str), f'{repr(func_label)} not string.'
+    # Else, "func_labeller" is passed. In this case...
+    else:
+        assert callable(func_labeller), f'{repr(func_labeller)} uncallable.'
 
     # If that function's name is already in this local scope, the caller
     # already declared a local attribute whose name collides with that
     # function's. In this case, raise an exception for safety.
     if func_name in func_locals:
         raise exception_cls(
-            f'{func_label} already defined by caller locals:\n'
+            f'{func_label or func_labeller()} '  # type: ignore[misc]
+            f'already defined by caller locals:\n'
             f'{repr(func_locals)}'
         )
     # Else, that function's name is *NOT* already in this local scope.
@@ -163,10 +197,10 @@ def make_func(
     # with this function.
     func_filename_name: str = None  # type: ignore[assignment]
 
-    # If this function is a high-level wrapper wrapping a lower-level
-    # wrappee, uniquify the subsequent filename against this wrappee. This
-    # wrappee's fully-qualified name guarantees the uniqueness of this
-    # filename. Ergo, this is the ideal case.
+    # If this function is a high-level wrapper wrapping a lower-level wrappee,
+    # uniquify the subsequent filename against this wrappee. This wrappee's
+    # fully-qualified name guarantees the uniqueness of this filename. Ergo,
+    # this is the ideal case.
     if func_wrapped:
         func_filename_name = get_object_name(func_wrapped)
         func_filename_object = func_wrapped
@@ -217,7 +251,7 @@ def make_func(
 
     # If debugging this function, print the definition of this function.
     if is_debug:
-        print(f'{number_lines(func_code)}')
+        print(f'{number_str_lines(func_code)}')
     # else:
     #     print('!!!!!!!!!PRINTING NOTHING!!!!!!!!!!!')
     # Else, leave that definition obscured by the voracious bitbuckets of time.
@@ -255,9 +289,10 @@ def make_func(
         #          ^
         #     SyntaxError: invalid syntax
         raise exception_cls(
-            f'{func_label} unparseable, as @beartype generated '
-            f'invalid code raising "{label_exception(exception)}":\n\n'
-            f'{number_lines(func_code)}'
+            f'{func_label or func_labeller()} '  # type: ignore[misc]
+            f'unparseable, as @beartype generated invalid code raising:\n'
+            f'\t{label_exception(exception)}\n\n'
+            f'{number_str_lines(func_code)}'
         ) from exception
 
     # ..................{ VALIDATION ~ post                  }..................
@@ -265,8 +300,9 @@ def make_func(
     # failed to declare that function. In this case, raise an exception.
     if func_name not in func_locals:
         raise exception_cls(
-            f'{func_label} undefined by code snippet:\n\n'
-            f'{number_lines(func_code)}'
+            f'{func_label or func_labeller()} '  # type: ignore[misc]
+            f'undefined by code snippet:\n\n'
+            f'{number_str_lines(func_code)}'
         )
     # Else, that function's name is in this local scope.
 
@@ -276,14 +312,15 @@ def make_func(
     # If that function is uncallable, raise an exception.
     if not callable(func):
         raise exception_cls(
-            f'{func_label} defined by code snippet uncallable:\n\n'
-            f'{number_lines(func_code)}'
+            f'{func_label or func_labeller()} '  # type: ignore[misc]
+            f'defined by code snippet uncallable:\n\n'
+            f'{number_str_lines(func_code)}'
         )
     # Else, that function is callable.
-
+    #
     # If that function is a wrapper wrapping a wrappee callable, propagate
     # dunder attributes from that wrappee onto this wrapper.
-    if func_wrapped is not None:
+    elif func_wrapped is not None:
         assert callable(func_wrapped), f'{repr(func_wrapped)} uncallable.'
         update_wrapper(wrapper=func, wrapped=func_wrapped)
     # Else, that function is *NOT* such a wrapper.
@@ -326,11 +363,11 @@ def make_func(
         )
 
         # Define and register a cleanup callback removing that function's
-        # linecache entry called if and when that function is
-        # garbage-collected.
+        # linecache entry called if and when that function is garbage-collected.
         def _remove_func_linecache_entry():
             linecache_cache.pop(func_filename, None)
         finalize(func, _remove_func_linecache_entry)
+    # Else, this function is *NOT* being debugged.
 
     # Return that function.
     return func
