@@ -1,10 +1,10 @@
 #!/usr/bin/env python3
 # --------------------( LICENSE                            )--------------------
-# Copyright (c) 2014-2023 Beartype authors.
+# Copyright (c) 2014-2025 Beartype authors.
 # See "LICENSE" for further details.
 
 """
-**Beartype string munging utilities** (i.e., callables transforming passed
+Project-wide **string munging utilities** (i.e., callables transforming passed
 strings into new strings with generic string operations).
 
 This private submodule is *not* intended for importation by downstream callers.
@@ -15,6 +15,37 @@ from beartype.roar._roarexc import _BeartypeUtilTextException
 from beartype._data.kind.datakindtext import CHARS_PUNCTUATION
 
 # ....................{ CASERS                             }....................
+#FIXME: Unit test us up, please.
+def lowercase_str_char_first(text: str) -> str:
+    '''
+    Lowercase *only* the first character of the passed string.
+
+    Parameters
+    ----------
+    text : str
+        String whose first character is to be lowercased.
+
+    Returns
+    -------
+    str
+        This string with the first character lowercased.
+    '''
+    assert isinstance(text, str), f'{repr(text)} not string.'
+
+    # If...
+    if (
+        # This string contains at least two characters *AND*...
+        len(text) >= 2 and
+        # The first character of this string is uppercase...
+        text[0].isupper()
+    ):
+        # Then lowercase only this character for readability.
+        text = f'{text[0].lower()}{text[1:]}'
+
+    # Return this possibly changed string.
+    return text
+
+
 def uppercase_str_char_first(text: str) -> str:
     '''
     Uppercase *only* the first character of the passed string.
@@ -30,7 +61,7 @@ def uppercase_str_char_first(text: str) -> str:
         String whose first character is to be uppercased.
 
     Returns
-    ----------
+    -------
     str
         This string with the first character uppercased.
     '''
@@ -43,7 +74,7 @@ def uppercase_str_char_first(text: str) -> str:
         # The first character of this string is lowercase...
         text[0].islower()
     ):
-        # Then uppercase only this string for readability.
+        # Then uppercase only this character for readability.
         text = f'{text[0].upper()}{text[1:]}'
 
     # Return this possibly changed string.
@@ -61,7 +92,7 @@ def number_str_lines(text: str) -> str:
         String whose lines are to be numbered.
 
     Returns
-    ----------
+    -------
     str
         This string with all lines numbered.
     '''
@@ -69,9 +100,11 @@ def number_str_lines(text: str) -> str:
 
     # For radical benevolence!
     return '\n'.join(
+        # Note that a format() call rather than f-string is intentionally
+        # applied here, as the former affords more functionality for string
+        # munging than the latter.
         '(line {:0>4d}) {}'.format(text_line_number, text_line)
-        for text_line_number, text_line in enumerate(
-            text.splitlines(), start=1)
+        for text_line_number, text_line in enumerate(text.splitlines(), start=1)
     )
 
 # ....................{ REPLACERS                          }....................
@@ -83,7 +116,7 @@ def replace_str_substrs(text: str, old: str, new: str) -> str:
     contains *no* such instance).
 
     Caveats
-    ----------
+    -------
     **This higher-level function should always be called in lieu of the
     lower-level** :meth:`str.replace` method, which unconditionally succeeds
     regardless of whether this subject string contains at least one instance of
@@ -100,19 +133,19 @@ def replace_str_substrs(text: str, old: str, new: str) -> str:
         subject string.
 
     Returns
-    ----------
+    -------
     str
         Subject string with all instances of this source substring globally
         replaced by this target substring.
 
     Raises
-    ----------
+    ------
     _BeartypeUtilTextException
         If this subject string contains *no* instances of this source
         substring.
 
     Examples
-    ----------
+    --------
         >>> from beartype._util.text.utiltextmunge import replace_str_substrs
         >>> replace_str_substrs(
         ...     text='And now the STORM-BLAST came, and he',
@@ -153,7 +186,7 @@ def suffix_str_unless_suffixed(text: str, suffix: str) -> str:
         Suffix to be conditionally appended to this string.
 
     Returns
-    ----------
+    -------
     str
         Either:
 
@@ -186,7 +219,7 @@ def truncate_str(
       replaced by an ASCII ellipsis (i.e., ``"..."`` substring).
 
     Caveats
-    ----------
+    -------
     **This function is unavoidably slow and should thus not be called from
     optimized performance-critical code.** This function internally performs
     mildly expensive operations, including iterating-based string munging.
@@ -202,7 +235,7 @@ def truncate_str(
         line length of 100 characters minus output indentation of 4 characters.
 
     Returns
-    ----------
+    -------
     str
         This string possibly truncated.
     '''
