@@ -1,6 +1,6 @@
 #!/usr/bin/env python3
 # --------------------( LICENSE                            )--------------------
-# Copyright (c) 2014-2024 Beartype authors.
+# Copyright (c) 2014-2025 Beartype authors.
 # See "LICENSE" for further details.
 
 '''
@@ -14,9 +14,7 @@ This private submodule is *not* intended for importation by downstream callers.
 '''
 
 # ....................{ IMPORTS                            }....................
-from ast import (
-    PyCF_ONLY_AST,
-)
+from ast import PyCF_ONLY_AST
 from beartype.claw._ast.clawastmain import BeartypeNodeTransformer
 from beartype.claw._importlib.clawimpcache import (  # type: ignore[attr-defined]
     cache_from_source_beartype,
@@ -24,7 +22,7 @@ from beartype.claw._importlib.clawimpcache import (  # type: ignore[attr-defined
 )
 from beartype.roar import BeartypeClawImportAstException
 from beartype.typing import Optional
-from beartype._conf.confcls import BeartypeConf
+from beartype._conf.confmain import BeartypeConf
 from beartype._util.ast.utilastget import get_node_repr_indented
 from beartype._util.text.utiltextlabel import label_exception
 from importlib import (  # type: ignore[attr-defined]
@@ -112,7 +110,7 @@ class BeartypeSourceFileLoader(SourceFileLoader):
 
     Attributes
     ----------
-    _module_conf_beartype : Optional[BeartypeConf]
+    _module_conf : Optional[BeartypeConf]
         Either:
 
         * If the most recent call to the :meth:`get_code` method (which loads a
@@ -125,26 +123,26 @@ class BeartypeSourceFileLoader(SourceFileLoader):
         * Else, :data:`None`.
 
         This instance variable enables our override of the parent
-        :meth:`get_code` method to communicate this configuration to the child
-        :meth:`source_to_code` method, which fails to accept and thus has *no*
+        :meth:`.get_code` method to communicate this configuration to the child
+        :meth:`.source_to_code` method, which fails to accept and thus has *no*
         access to this module name. The superclass implementation of the
-        :meth:`get_code` method then internally calls our override of the
-        :meth:`source_to_code` method, which accesses this instance variable to
+        :meth:`.get_code` method then internally calls our override of the
+        :meth:`.source_to_code` method, which accesses this instance variable to
         decide whether and how to type-check that module.
 
         Ordinarily, this approach would be fraught with fragility. For example,
         what if something *other* than the :meth:`get_code` method called the
-        :meth:`source_to_code` method? Thankfully, that is *not* a concern here.
-        :meth:`source_to_code` is only called by :meth:`get_code` in the
+        :meth:`.source_to_code` method? Thankfully, that is *not* a concern here.
+        :meth:`.source_to_code` is only called by :meth:`get_code` in the
         :mod:`importlib` codebase. Ergo, :meth:`source_to_code` should ideally
         have been privatized (e.g., as ``_source_to_code()``).
-    _module_name_beartype : str
+    _module_name : str
         Fully-qualified name of the module currently being imported by the
-        :meth:`get_code` method for subsequent reference in the lower-level
-        :meth:`source_to_code` method transitively called by the former.
+        :meth:`.get_code` method for subsequent reference in the lower-level
+        :meth:`.source_to_code` method transitively called by the former.
 
     See Also
-    ----------
+    --------
     * The `comparable "typeguard.importhook" submodule <typeguard import
       hook_>`__ implemented by the incomparable `@agronholm (Alex Grönholm)
       <agronholm_>`__, whose intrepid solutions strongly inspired this
@@ -173,8 +171,8 @@ class BeartypeSourceFileLoader(SourceFileLoader):
         super().__init__(*args, **kwargs)
 
         # Nullify all subclass-specific instance variables for safety.
-        self._module_conf_beartype: Optional[BeartypeConf] = None
-        self._module_name_beartype: str = ''
+        self._module_conf: Optional[BeartypeConf] = None
+        self._module_name: str = None  # type: ignore[assignment]
 
     # ..................{ LOADER API                         }..................
     # The importlib._bootstrap_external.*Loader API declares the low-level
@@ -199,19 +197,19 @@ class BeartypeSourceFileLoader(SourceFileLoader):
         internally follows one of two distinct code paths, conditionally
         depending on whether a parent package transitively containing that
         module has been previously registered with the
-        :mod:`beartype.claw._pkg.clawpkghook` submodule (e.g., by a call to the
-        :func:`beartype.claw.beartype_package` function). Specifically:
+        :mod:`beartype.claw._package.clawpkghook` submodule (e.g., by a call to
+        the :func:`beartype.claw.beartype_package` function). Specifically:
 
         * If *no* parent package transitively containing that module has been
           registered, this method fully defers to the superclass
-          :meth:`SourceLoader.get_code` method.
+          :meth:`.SourceLoader.get_code` method.
         * Else, one or more parent packages transitively containing that module
           have been registered. In this case, this method (in order):
 
           #. Temporarily monkey-patches (i.e., replaces) the
              private :func:`importlib._bootstrap_external.cache_from_source`
              function with our beartype-specific
-             :func:`_cache_from_source_beartype` variant.
+             :func:`cache_from_source_beartype` variant.
           #. Calls the superclass :meth:`SourceLoader.get_code` method, which:
 
              #. Calls our override of the lower-level superclass
@@ -273,7 +271,7 @@ class BeartypeSourceFileLoader(SourceFileLoader):
         that really bears repeating. May the name of Alex Grönholm live eternal!
 
         Caveats
-        ----------
+        -------
         This getter intentionally avoids all dangerous attempts to recursively
         type-check the :mod:`beartype` package by the :func:`beartype.beartype`
         decorator. Doing so would be:
@@ -308,37 +306,45 @@ class BeartypeSourceFileLoader(SourceFileLoader):
             Fully-qualified name of the module currently being imported.
 
         Returns
-        ----------
+        -------
         Optional[CodeType]
             Code object underlying that module.
         '''
 
         # Avoid circular import dependencies.
         from beartype.claw._clawstate import claw_state
-        from beartype.claw._pkg.clawpkgtrie import get_package_conf_or_none
+        from beartype.claw._package.clawpkgtrie import get_package_conf_or_none
 
         # Beartype configuration with which to type-check that module if that
-        # module is hooked *OR* "None" otherwise (i.e., if that module is
-        # unhooked), defined as either...
-        conf = (
-            # If that module is either the top-level "beartype" package *OR* a
-            # subpackage or submodule of that package, "None". This effectively
-            # silently ignores this dangerous attempt to recursively type-check
-            # the "beartype" package by the @beartype.beartype decorator. See
-            # the method docstring for further commentary.
-            None
-            if (
-                fullname == 'beartype' or
-                fullname.startswith('beartype.')
-            ) else
-            # Else, that module is neither our top-level "beartype" package
-            # *NOR* a subpackage or submodule of that package. In this case, the
-            # beartype configuration with which to type-check that module if
-            # that module is hooked under its fully-qualified name *OR*
-            # "None" otherwise (i.e., if that module is unhooked).
-            get_package_conf_or_none(fullname)
-        )
-        # print(f'Imported module "{fullname}" package "{package_name}" conf: {repr(self._module_conf_beartype)}')
+        # module is hooked under its fully-qualified name *OR* "None" otherwise
+        # (i.e., if that module is unhooked).
+        conf = get_package_conf_or_none(fullname)
+
+        #FIXME: Preserved because the above will inevitably break. *sigh*
+        # # Beartype configuration with which to type-check that module if that
+        # # module is hooked *OR* "None" otherwise (i.e., if that module is
+        # # unhooked), defined as either...
+        # conf = (
+        #     #FIXME: *EXCISE*. The same logic is now redundantly performed by the
+        #     #BeartypeClawState._reinit_safe() method.
+        #     # If that module is either the top-level "beartype" package *OR* a
+        #     # subpackage or submodule of that package, "None". This effectively
+        #     # silently ignores this dangerous attempt to recursively type-check
+        #     # the "beartype" package by the @beartype.beartype decorator. See
+        #     # the method docstring for further commentary.
+        #     None
+        #     if (
+        #         fullname == 'beartype' or
+        #         fullname.startswith('beartype.')
+        #     ) else
+        #     # Else, that module is neither our top-level "beartype" package
+        #     # *NOR* a subpackage or submodule of that package. In this case, the
+        #     # beartype configuration with which to type-check that module if
+        #     # that module is hooked under its fully-qualified name *OR*
+        #     # "None" otherwise (i.e., if that module is unhooked).
+        #     get_package_conf_or_none(fullname)
+        # )
+        # print(f'Imported module "{fullname}" package "{package_name}" conf: {repr(self._module_conf)}')
 
         # If that module is unhooked, preserve that module as is by simply
         # deferring to the superclass method *WITHOUT* monkey-patching
@@ -354,30 +360,31 @@ class BeartypeSourceFileLoader(SourceFileLoader):
         # Note that the logic below requires inefficient exception handling (as
         # well as a potentially risky monkey-patch) and is thus performed *ONLY*
         # when absolutely necessary.
-        else:
-            # Classify local attributes as instance variables for subsequent
-            # reference in the lower-level source_to_code() method transitively
-            # called by this higher-level method.
-            self._module_conf_beartype = conf
-            self._module_name_beartype = fullname
 
-            # Expose this configuration to the "beartype.claw._ast" subpackage.
-            claw_state.module_name_to_beartype_conf[fullname] = conf
+        # Classify local attributes as instance variables for subsequent
+        # reference in the lower-level source_to_code() method transitively
+        # called by this higher-level method.
+        self._module_conf = conf
+        self._module_name = fullname
 
-            # Temporarily monkey-patch away the cache_from_source() function.
-            #
-            # Note that @agronholm (Alex Grönholm) claims that "the import lock
-            # should make this monkey patch safe." We're trusting you here, man!
-            _bootstrap_external.cache_from_source = cache_from_source_beartype
+        # Expose this configuration to the "beartype.claw._ast" subpackage.
+        claw_state.module_name_to_beartype_conf[fullname] = conf
 
-            # Attempt to defer to the superclass method.
-            try:
-                return super().get_code(fullname)
-            # After doing so (and regardless of whether doing so raises an
-            # exception), restore the original cache_from_source() function.
-            finally:
-                _bootstrap_external.cache_from_source = (
-                    cache_from_source_original)
+        # Temporarily monkey-patch away the cache_from_source() function.
+        #
+        # Note that @agronholm (Alex Grönholm) claims that "the import lock
+        # should make this monkey patch safe." We're trusting you here, man!
+        _bootstrap_external.cache_from_source = cache_from_source_beartype
+
+        # Attempt to defer to the superclass method.
+        try:
+            # print(f'Importing module "{fullname}" with beartyping...')
+            return super().get_code(fullname)
+        # After doing so (and regardless of whether doing so raises an
+        # exception), restore the original cache_from_source() function.
+        finally:
+            _bootstrap_external.cache_from_source = (
+                cache_from_source_original)
 
 
     # Note that we explicitly ignore mypy override complaints here. For unknown
@@ -422,22 +429,28 @@ class BeartypeSourceFileLoader(SourceFileLoader):
             initially invoked (e.g., via the ``-o`` command-line option).
 
         Returns
-        ----------
+        -------
         CodeType
             Code object dynamically compiled from that Python package or module.
 
         Raises
-        ----------
+        ------
         BeartypeClawImportAstException
             If our **beartype node transformer** (i.e.,
             :class:`.BeartypeNodeTransformer` instance) dynamically transforms
             the original valid abstract syntax tree (AST) governing that Python
             package or module into a new invalid AST.
         '''
+        #NOTETOSELF: If you uncomment this and don't see any output, then
+        #bytecode caching is the culprit. Unit or integration tests are probably
+        #failing to properly clear the appropriate bytecode cache. *sigh*
+        # from sys import stderr
+        # print('!!!TRANSFORMING!!!', file=stderr)
+        # print('!!!TRANSFORMING!!!')
 
         # If that module has *NOT* been registered for type-checking, preserve
         # that module as is by simply deferring to the superclass method.
-        if self._module_conf_beartype is None:
+        if self._module_conf is None:
             return super().source_to_code(  # type: ignore[call-arg]
                 data=data, path=path, _optimize=_optimize)  # pyright: ignore
         # Else, that module has been registered for type-checking.
@@ -459,7 +472,7 @@ class BeartypeSourceFileLoader(SourceFileLoader):
 
         # AST transformer decorating typed callables and classes by @beartype.
         ast_beartyper = BeartypeNodeTransformer(
-            conf_beartype=self._module_conf_beartype)
+            module_name=self._module_name, conf=self._module_conf)
 
         # Abstract syntax tree (AST) modified by this transformer.
         module_ast_beartyped = ast_beartyper.visit(module_ast)
@@ -471,7 +484,7 @@ class BeartypeSourceFileLoader(SourceFileLoader):
         # from sys import stderr
         # print(
         #     (
-        #         f'Module "{self._module_name_beartype}" abstract syntax tree (AST) '
+        #         f'Module "{self._module_name}" abstract syntax tree (AST) '
         #         f'transformed by @beartype to:\n\n'
         #         f'{get_node_repr_indented(module_ast_beartyped)}'
         #     ),
@@ -496,7 +509,7 @@ class BeartypeSourceFileLoader(SourceFileLoader):
         # Doing so enables users to submit meaningful issues to our tracker.
         except Exception as exception:
             raise BeartypeClawImportAstException(
-                f'Module "{self._module_name_beartype}" unimportable, as '
+                f'Module "{self._module_name}" unimportable, as '
                 f'@beartype generated invalid '
                 f'abstract syntax tree (AST):\n\n'
                 f'{get_node_repr_indented(module_ast_beartyped)}\n\n'
