@@ -1,6 +1,6 @@
 #!/usr/bin/env python3
 # --------------------( LICENSE                            )--------------------
-# Copyright (c) 2014-2023 Beartype authors.
+# Copyright (c) 2014-2025 Beartype authors.
 # See "LICENSE" for further details.
 
 '''
@@ -19,44 +19,44 @@ the attributes declared by :mod:`typing`, notable differences include:
   Python 3.8-specific version of the :mod:`typing` module, thus preserving
   forward compatibility with future Python versions. These include:
 
-  * :attr:`typing.AbstractSet`.
-  * :attr:`typing.AsyncContextManager`.
-  * :attr:`typing.AsyncGenerator`.
-  * :attr:`typing.AsyncIterable`.
-  * :attr:`typing.AsyncIterator`.
-  * :attr:`typing.Awaitable`.
-  * :attr:`typing.ByteString`.
-  * :attr:`typing.Callable`.
-  * :attr:`typing.ChainMap`.
-  * :attr:`typing.Collection`.
-  * :attr:`typing.Container`.
-  * :attr:`typing.ContextManager`.
-  * :attr:`typing.Coroutine`.
-  * :attr:`typing.Counter`.
-  * :attr:`typing.DefaultDict`.
-  * :attr:`typing.Deque`.
-  * :attr:`typing.Dict`.
-  * :attr:`typing.FrozenSet`.
-  * :attr:`typing.Generator`.
-  * :attr:`typing.ItemsView`.
-  * :attr:`typing.Iterable`.
-  * :attr:`typing.Iterator`.
-  * :attr:`typing.KeysView`.
-  * :attr:`typing.List`.
-  * :attr:`typing.Mapping`.
-  * :attr:`typing.MappingView`.
-  * :attr:`typing.Match`.
-  * :attr:`typing.MutableMapping`.
-  * :attr:`typing.MutableSequence`.
-  * :attr:`typing.MutableSet`.
-  * :attr:`typing.OrderedDict`.
-  * :attr:`typing.Pattern`.
-  * :attr:`typing.Reversible`.
-  * :attr:`typing.Set`.
-  * :attr:`typing.Tuple`.
-  * :attr:`typing.Type`.
-  * :attr:`typing.Sequence`.
-  * :attr:`typing.ValuesView`.
+  * :obj:`typing.AbstractSet`.
+  * :obj:`typing.AsyncContextManager`.
+  * :obj:`typing.AsyncGenerator`.
+  * :obj:`typing.AsyncIterable`.
+  * :obj:`typing.AsyncIterator`.
+  * :obj:`typing.Awaitable`.
+  * :obj:`typing.ByteString`.
+  * :obj:`typing.Callable`.
+  * :obj:`typing.ChainMap`.
+  * :obj:`typing.Collection`.
+  * :obj:`typing.Container`.
+  * :obj:`typing.ContextManager`.
+  * :obj:`typing.Coroutine`.
+  * :obj:`typing.Counter`.
+  * :obj:`typing.DefaultDict`.
+  * :obj:`typing.Deque`.
+  * :obj:`typing.Dict`.
+  * :obj:`typing.FrozenSet`.
+  * :obj:`typing.Generator`.
+  * :obj:`typing.ItemsView`.
+  * :obj:`typing.Iterable`.
+  * :obj:`typing.Iterator`.
+  * :obj:`typing.KeysView`.
+  * :obj:`typing.List`.
+  * :obj:`typing.Mapping`.
+  * :obj:`typing.MappingView`.
+  * :obj:`typing.Match`.
+  * :obj:`typing.MutableMapping`.
+  * :obj:`typing.MutableSequence`.
+  * :obj:`typing.MutableSet`.
+  * :obj:`typing.OrderedDict`.
+  * :obj:`typing.Pattern`.
+  * :obj:`typing.Reversible`.
+  * :obj:`typing.Set`.
+  * :obj:`typing.Tuple`.
+  * :obj:`typing.Type`.
+  * :obj:`typing.Sequence`.
+  * :obj:`typing.ValuesView`.
 
 Usage
 ----------
@@ -103,7 +103,7 @@ this submodule rather than from :mod:`typing` directly: e.g.,
 #        #submodules of a new "beartype.typing._util" subpackage.
 #        # Import the requisite machinery that will make the magic happen.
 #        from beartype._util.hint.utilhintfactory import TypeHintTypeFactory
-#        from beartype._util.module.lib.utiltyping import (
+#        from beartype._util.api.standard.utiltyping import (
 #            import_typing_attr_or_fallback as _import_typing_attr_or_fallback)
 #
 #        # Dynamically define the "Self" type hint as follows:
@@ -134,9 +134,14 @@ this submodule rather than from :mod:`typing` directly: e.g.,
 # "import_typing_attr_or_none('Annotated')").
 #!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
 from beartype._util.py.utilpyversion import (
+    IS_PYTHON_AT_MOST_3_16  as _IS_PYTHON_AT_MOST_3_16,
+    IS_PYTHON_AT_MOST_3_15  as _IS_PYTHON_AT_MOST_3_15,
+    IS_PYTHON_AT_MOST_3_13  as _IS_PYTHON_AT_MOST_3_13,
+    IS_PYTHON_AT_LEAST_3_14 as _IS_PYTHON_AT_LEAST_3_14,
+    IS_PYTHON_AT_LEAST_3_13 as _IS_PYTHON_AT_LEAST_3_13,
+    IS_PYTHON_AT_LEAST_3_12 as _IS_PYTHON_AT_LEAST_3_12,
     IS_PYTHON_AT_LEAST_3_11 as _IS_PYTHON_AT_LEAST_3_11,
     IS_PYTHON_AT_LEAST_3_10 as _IS_PYTHON_AT_LEAST_3_10,
-    IS_PYTHON_AT_LEAST_3_9  as _IS_PYTHON_AT_LEAST_3_9,
 )
 
 # ....................{ IMPORTS ~ all                      }....................
@@ -157,47 +162,44 @@ from beartype._util.py.utilpyversion import (
 from typing import (
     TYPE_CHECKING as TYPE_CHECKING,
     Any as Any,
-    AnyStr as AnyStr,
+    Annotated as Annotated,
     BinaryIO as BinaryIO,
     ClassVar as ClassVar,
-    Final as Final,  # pyright: ignore[reportGeneralTypeIssues]
+    Final as Final,  # pyright: ignore
     ForwardRef as ForwardRef,
     Generic as Generic,
-    Hashable as Hashable,
     IO as IO,
-    Literal as Literal,  # pyright: ignore[reportGeneralTypeIssues]
+    Literal as Literal,  # pyright: ignore
     NewType as NewType,
     NamedTuple as NamedTuple,
     NoReturn as NoReturn,
     Optional as Optional,
-    Reversible as Reversible,  # pyright: ignore[reportGeneralTypeIssues]
-    Sized as Sized,
-    SupportsIndex as SupportsIndex,  # pyright: ignore[reportGeneralTypeIssues]
-    TypedDict as TypedDict,  # pyright: ignore[reportGeneralTypeIssues]
+    Reversible as Reversible,  # pyright: ignore
+    TypedDict as TypedDict,  # pyright: ignore
     Text as Text,
     TextIO as TextIO,
     TypeVar as TypeVar,
     Union as Union,
     cast as cast,
-    final as final,  # pyright: ignore[reportGeneralTypeIssues]
-    get_args as get_args,  # pyright: ignore[reportGeneralTypeIssues]
-    get_origin as get_origin,  # pyright: ignore[reportGeneralTypeIssues]
+    final as final,  # pyright: ignore
+    get_args as get_args,  # pyright: ignore
+    get_origin as get_origin,  # pyright: ignore
     get_type_hints as get_type_hints,
     no_type_check as no_type_check,
     no_type_check_decorator as no_type_check_decorator,
     overload as overload,
 )
 
-# ....................{ IMPORTS ~ version                  }....................
-# Import all public attributes of the "typing" module both available under a
-# subset of supported Python versions and *NOT* deprecated by a subsequent
-# Python version under their original names.
+# ....................{ IMPORTS ~ version : at least       }....................
+# Import all public attributes of the "typing" module both available under at
+# least some Python interpreter version *AN* not yet deprecated by a subsequent
+# Python interpreter version under their original names.
 
 #FIXME: mypy is now emitting non-fatal warnings about our failing to import from
 #"typing_extensions", which is both an overly strongly opinionated position for
-#mypy to stake out *AND* a bad opinion at that, because "typing_extensions"
-#fails to comply with the runtime API of the "typing" module and is thus mostly
-#unusable at runtime. These warnings resemble:
+#mypy to stake out *AND* a bad opinion at that, because "typing_extensions" is
+#a third-party package. Ideally, mypy shouldn't be pushing *ANY* third-party
+#packages. These warnings resemble:
 #    beartype/typing/__init__.py:145: note: Use `from typing_extensions import Final` instead
 #    beartype/typing/__init__.py:145: note: See https://mypy.readthedocs.io/en/stable/runtime_troubles.html#using-new-additions-to-the-typing-module
 #    beartype/typing/__init__.py:145: note: Use `from typing_extensions import Literal` instead
@@ -218,49 +220,97 @@ from typing import (
 # If the active Python interpreter targets Python >= 3.10...
 if _IS_PYTHON_AT_LEAST_3_10:
     from typing import (  # type: ignore[attr-defined]
-        Concatenate as Concatenate,  # pyright: ignore[reportGeneralTypeIssues]
-        ParamSpec as ParamSpec,  # pyright: ignore[reportGeneralTypeIssues]
-        ParamSpecArgs as ParamSpecArgs,  # pyright: ignore[reportGeneralTypeIssues]
-        ParamSpecKwargs as ParamSpecKwargs,  # pyright: ignore[reportGeneralTypeIssues]
-        TypeAlias as TypeAlias,  # pyright: ignore[reportGeneralTypeIssues]
-        TypeGuard as TypeGuard,  # pyright: ignore[reportGeneralTypeIssues]
-        is_typeddict as is_typeddict,  # pyright: ignore[reportGeneralTypeIssues]
+        Concatenate as Concatenate,  # pyright: ignore
+        ParamSpec as ParamSpec,  # pyright: ignore
+        ParamSpecArgs as ParamSpecArgs,  # pyright: ignore
+        ParamSpecKwargs as ParamSpecKwargs,  # pyright: ignore
+        TypeAlias as TypeAlias,  # pyright: ignore
+        TypeGuard as TypeGuard,  # pyright: ignore
+        is_typeddict as is_typeddict,  # pyright: ignore
     )
 
     # If the active Python interpreter targets Python >= 3.11...
     if _IS_PYTHON_AT_LEAST_3_11:
         from typing import (  # type: ignore[attr-defined]
-               LiteralString as LiteralString,  # pyright: ignore[reportGeneralTypeIssues]
-               Never as Never,  # pyright: ignore[reportGeneralTypeIssues]
-               NotRequired as NotRequired,  # pyright: ignore[reportGeneralTypeIssues]
-               Required as Required,  # pyright: ignore[reportGeneralTypeIssues]
-               Self as Self,  # pyright: ignore[reportGeneralTypeIssues]
-               TypeVarTuple as TypeVarTuple,  # pyright: ignore[reportGeneralTypeIssues]
-               Unpack as Unpack,  # pyright: ignore[reportGeneralTypeIssues]
-               assert_never as assert_never,  # pyright: ignore[reportGeneralTypeIssues]
-               assert_type as assert_type,  # pyright: ignore[reportGeneralTypeIssues]
-               clear_overloads as clear_overloads,  # pyright: ignore[reportGeneralTypeIssues]
-               dataclass_transform as dataclass_transform,  # pyright: ignore[reportGeneralTypeIssues]
-               reveal_type as reveal_type,  # pyright: ignore[reportGeneralTypeIssues]
-               get_overloads as get_overloads,  # pyright: ignore[reportGeneralTypeIssues]
-               reveal_type as reveal_type,  # pyright: ignore[reportGeneralTypeIssues]
+           LiteralString as LiteralString,  # pyright: ignore
+           Never as Never,  # pyright: ignore
+           NotRequired as NotRequired,  # pyright: ignore
+           Required as Required,  # pyright: ignore
+           Self as Self,  # pyright: ignore
+           TypeVarTuple as TypeVarTuple,  # pyright: ignore
+           Unpack as Unpack,  # pyright: ignore
+           assert_never as assert_never,  # pyright: ignore
+           assert_type as assert_type,  # pyright: ignore
+           clear_overloads as clear_overloads,  # pyright: ignore
+           dataclass_transform as dataclass_transform,  # pyright: ignore
+           get_overloads as get_overloads,  # pyright: ignore
+           reveal_type as reveal_type,  # pyright: ignore
         )
 
+        # If the active Python interpreter targets Python >= 3.12...
+        if _IS_PYTHON_AT_LEAST_3_12:
+            from typing import (  # type: ignore[attr-defined]
+                TypeAliasType as TypeAliasType,  # pyright: ignore
+                override as override,  # pyright: ignore
+            )
+
+            # If the active Python interpreter targets Python >= 3.13...
+            if _IS_PYTHON_AT_LEAST_3_13:
+                from typing import (  # type: ignore[attr-defined]
+                    NoDefault as NoDefault,  # pyright: ignore
+                    ReadOnly as ReadOnly,  # pyright: ignore
+                    TypeIs as TypeIs,  # pyright: ignore
+                    get_protocol_members as get_protocol_members,  # pyright: ignore
+                    is_protocol as is_protocol,  # pyright: ignore
+                )
+
+                # If the active Python interpreter targets Python >= 3.14...
+                if _IS_PYTHON_AT_LEAST_3_14:
+                    from typing import (  # type: ignore[attr-defined]
+                        evaluate_forward_ref as evaluate_forward_ref,  # pyright: ignore
+                    )
+
+# ....................{ IMPORTS ~ version : at most        }....................
+# Import all public attributes of the "typing" module both available under at
+# most some Python interpreter version (typically due to having been deprecated
+# by a prior Python interpreter version).
+
+# If the active Python interpreter targets at most Python <= 3.16...
+if _IS_PYTHON_AT_MOST_3_16:
+    # Import the PEP 585-compliant "collections.abc.ByteString" attribute
+    # under 3.9 <= Python <= 3.13. Both "collections.abc.ByteString" *AND*
+    # "typing.ByteString" have been scheduled for removal under Python 3.17 by
+    # the upstream CPython issue:
+    #     https://github.com/python/cpython/issues/91896
+    #
+    # Note that these attributes were originally scheduled for removal under
+    # Python 3.14. This removal was since deferred by three minor versions (and
+    # thus three years) to inform downstream third-party packages with proper
+    # "DeprecationWarning" warnings emitted by the "typing" module.
+    from collections.abc import ByteString as ByteString  # type: ignore[attr-defined]
+
+    # If the active Python interpreter targets at most Python <= 3.15...
+    if _IS_PYTHON_AT_MOST_3_15:
+        # Import the PEP 484-compliant "typing.AnyStr" attribute under 3.9 <=
+        # Python <= 3.15. This attribute has been scheduled for removal under
+        # Python 3.16 by the upstream CPython issue:
+        #     https://github.com/python/cpython/issues/105578
+        from typing import AnyStr as AnyStr
+
 # ....................{ PEP ~ 544                          }....................
 # If this interpreter is performing static type-checking (e.g., via mypy), defer
-# to the standard library versions of the family of "Supports*" protocols
-# available under Python < 3.8.
+# to the standard library versions of the family of "Supports*" protocols.
 if TYPE_CHECKING:
     from typing import (  # type: ignore[attr-defined]
-        Protocol as Protocol,  # pyright: ignore[reportGeneralTypeIssues]
+        Protocol as Protocol,  # pyright: ignore
         SupportsAbs as SupportsAbs,
         SupportsBytes as SupportsBytes,
         SupportsComplex as SupportsComplex,
         SupportsFloat as SupportsFloat,
-        SupportsIndex as SupportsIndex,  # pyright: ignore[reportGeneralTypeIssues]
+        SupportsIndex as SupportsIndex,  # pyright: ignore
         SupportsInt as SupportsInt,
         SupportsRound as SupportsRound,
-        runtime_checkable as runtime_checkable,  # pyright: ignore[reportGeneralTypeIssues]
+        runtime_checkable as runtime_checkable,  # pyright: ignore
     )
 # Else, this interpreter is *NOT* performing static type-checking. In this
 # case, prefer our optimized PEP 544 attributes.
@@ -278,17 +328,15 @@ else:
     )
 
 # ....................{ PEP ~ 585                          }....................
-# If this interpreter is either performing static type-checking (e.g., via mypy)
-# *OR* targets Python < 3.9 and thus fails to support PEP 585, import *ALL*
-# public attributes of the "typing" module deprecated by PEP 585 as their
-# original values.
+# If the active Python interpreter is performing static type-checking (e.g.,
+# "mypy"), import *ALL* public attributes of the "typing" module deprecated by
+# PEP 585 as their original values.
 #
-# This is intentionally performed *BEFORE* the corresponding "else:" branch
-# below handling the Python >= 3.9 case. Why? Because mypy. If the order of
-# these two branches is reversed, mypy emits errors under Python < 3.9 when
-# attempting to subscript any of the builtin types (e.g., "Tuple"): e.g.,
+# This is intentionally performed *BEFORE* the corresponding "else:" branch.
+# Why? Because "mypy". If the order of these two branches is reversed, "mypy"
+# emits errors when attempting to subscript *ANY* builtin type: e.g.,
 #     error: "tuple" is not subscriptable  [misc]
-if TYPE_CHECKING or not _IS_PYTHON_AT_LEAST_3_9:
+if TYPE_CHECKING:
     from typing import (
         AbstractSet as AbstractSet,
         AsyncContextManager as AsyncContextManager,
@@ -296,7 +344,6 @@ if TYPE_CHECKING or not _IS_PYTHON_AT_LEAST_3_9:
         AsyncIterable as AsyncIterable,
         AsyncIterator as AsyncIterator,
         Awaitable as Awaitable,
-        ByteString as ByteString,
         Callable as Callable,
         ChainMap as ChainMap,
         Collection as Collection,
@@ -309,6 +356,7 @@ if TYPE_CHECKING or not _IS_PYTHON_AT_LEAST_3_9:
         Dict as Dict,
         FrozenSet as FrozenSet,
         Generator as Generator,
+        Hashable as Hashable,
         ItemsView as ItemsView,
         Iterable as Iterable,
         Iterator as Iterator,
@@ -324,14 +372,15 @@ if TYPE_CHECKING or not _IS_PYTHON_AT_LEAST_3_9:
         Pattern as Pattern,
         Reversible as Reversible,
         Set as Set,
+        Sized as Sized,
         Tuple as Tuple,
         Type as Type,
         Sequence as Sequence,
         ValuesView as ValuesView,
     )
-# If the active Python interpreter targets Python >= 3.9 and thus supports PEP
-# 585, alias *ALL* public attributes of the "typing" module deprecated by PEP
-# 585 to their equivalent values elsewhere in the standard library.
+# Else, the active Python interpreter is *NOT* performing static type-checking.
+# In this case, alias *ALL* public attributes of the "typing" module deprecated
+# by PEP 585 to their equivalent values elsewhere in the standard library.
 else:
     from collections import (
         ChainMap as ChainMap,
@@ -345,12 +394,12 @@ else:
         AsyncIterator as AsyncIterator,
         AsyncGenerator as AsyncGenerator,
         Awaitable as Awaitable,
-        ByteString as ByteString,
         Callable as Callable,
         Collection as Collection,
         Container as Container,
         Coroutine as Coroutine,
         Generator as Generator,
+        Hashable as Hashable,
         ItemsView as ItemsView,
         Iterable as Iterable,
         Iterator as Iterator,
@@ -362,6 +411,7 @@ else:
         MutableSet as MutableSet,
         Reversible as Reversible,
         Sequence as Sequence,
+        Sized as Sized,
         ValuesView as ValuesView,
         Set as AbstractSet,
     )
@@ -373,9 +423,6 @@ else:
         Match as Match,
         Pattern as Pattern,
     )
-    from typing import (  # type: ignore[attr-defined]
-        Annotated,
-    )
 
     Dict = dict  # type: ignore[misc]
     FrozenSet = frozenset  # type: ignore[misc]
