@@ -1,6 +1,6 @@
 #!/usr/bin/env python3
 # --------------------( LICENSE                            )--------------------
-# Copyright (c) 2014-2024 Beartype authors.
+# Copyright (c) 2014-2025 Beartype authors.
 # See "LICENSE" for further details.
 
 '''
@@ -104,18 +104,17 @@ def skip_unless_godmode():
     # the current platform is vanilla Windows).
     username = get_shell_var_value_or_none('USER')
 
+    # Substring prefixing the reason given below.
+    reason_prefix = f'User "{username}" ' if username else 'Current user '
+
     # Skip this test if the current platform is POSIX-compatible *AND* the
     # current user invoking the active Python interpreter is *NOT* a
     # God-mode-endowed user (i.e., the principal maintainer of this package).
     return skip_if(
         username != 'leycec',
         reason=(
-            (
-                f'User "{username}" lacks God-mode test privileges '
-                f"(i.e., is smart and knows what's good for them)."
-            )
-            if username else
-            'Current platform POSIX-noncompliant.'
+            f'{reason_prefix}lacks God-mode test privileges '
+            f"(i.e., is smart and knows what's good for them)."
         ),
     )
 
@@ -167,6 +166,27 @@ def skip_if_ci():
     return skip_if(is_ci(), reason='Incompatible with CI workflows.')
 
 # ....................{ SKIP ~ os                          }....................
+def skip_if_os_windows():
+    '''
+    Skip the decorated test or fixture if the active Python interpreter is
+    running under **vanilla Microsoft Windows** (i.e., *not* running the Cygwin
+    POSIX compatibility layer).
+
+    Returns
+    -------
+    pytest.skipif
+        Decorator skipping this text or fixture unless this interpreter is
+        running under vanilla Microsoft Windows *or* the identity decorator
+        reducing to a noop otherwise.
+    '''
+
+    # Defer heavyweight imports.
+    from beartype._util.os.utilostest import is_os_windows_vanilla
+
+    # Skip this test if the current platform is Linux.
+    return skip_if(is_os_windows_vanilla(), reason='OS is vanilla Windows 32.')
+
+
 def skip_unless_os_linux():
     '''
     Skip the decorated test or fixture unless the active Python interpreter is
@@ -186,7 +206,7 @@ def skip_unless_os_linux():
     # Defer heavyweight imports.
     from beartype._util.os.utilostest import is_os_linux
 
-    # Skip this test unless the current platform is Linux
+    # Skip this test unless the current platform is Linux.
     return skip_if(not is_os_linux(), reason='OS not Linux.')
 
 # ....................{ SKIP ~ pep                         }....................
@@ -274,19 +294,14 @@ def skip_if_python_version_greater_than_or_equal_to(version: str):
     pytest.skipif
         Decorator describing these requirements if unmet *or* the identity
         decorator reducing to a noop otherwise.
-
-    See Also
-    --------
-    :mod:`beartype.meta`
-        Similar logic performed at :mod:`beartype` importation time.
     '''
     assert isinstance(version, str), f'{repr(version)} not string.'
 
     # Defer test-specific imports.
-    from beartype.meta import _convert_version_str_to_tuple
+    from beartype._util.text.utiltextversion import convert_str_version_to_tuple
 
     # Machine-readable required version of Python as a tuple of integers.
-    version_tuple = _convert_version_str_to_tuple(version)
+    version_tuple = convert_str_version_to_tuple(version)
 
     # Skip this test if the current Python version exceeds this requirement.
     return skip_if(
@@ -311,19 +326,14 @@ def skip_if_python_version_less_than(version: str):
     pytest.skipif
         Decorator describing these requirements if unmet *or* the identity
         decorator reducing to a noop otherwise.
-
-    See Also
-    --------
-    :mod:`beartype.meta`
-        Similar logic performed at :mod:`beartype` importation time.
     '''
     assert isinstance(version, str), f'{repr(version)} not string.'
 
     # Defer test-specific imports.
-    from beartype.meta import _convert_version_str_to_tuple
+    from beartype._util.text.utiltextversion import convert_str_version_to_tuple
 
     # Machine-readable required version of Python as a tuple of integers.
-    version_tuple = _convert_version_str_to_tuple(version)
+    version_tuple = convert_str_version_to_tuple(version)
 
     # Skip this test if the current Python version is less than this
     # requirement.
