@@ -1,6 +1,6 @@
 #!/usr/bin/env python3
 # --------------------( LICENSE                            )--------------------
-# Copyright (c) 2014-2023 Beartype authors.
+# Copyright (c) 2014-2025 Beartype authors.
 # See "LICENSE" for further details.
 
 '''
@@ -15,112 +15,98 @@ This submodule unit tests the public API of the private
 # WARNING: To raise human-readable test errors, avoid importing from
 # package-specific submodules at module scope.
 #!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
-from pytest import raises
 
 # ....................{ TESTS                              }....................
 # Fine-grained tests are intentionally performed *BEFORE* coarse-grained tests,
 # dramatically improving readability of test failures.
 
-# ....................{ TESTS ~ kind : typevar             }....................
-def test_is_hint_pep_typevars() -> None:
-    '''
-    Test the
-    :func:`beartype._util.hint.pep.utilpeptest.is_hint_pep_typevars`
-    tester.
-    '''
-
-    # Defer test-specific imports.
-    from beartype._util.hint.pep.utilpeptest import is_hint_pep_typevars
-    from beartype_test.a00_unit.data.hint.data_hint import HINTS_NONPEP
-    from beartype_test.a00_unit.data.hint.pep.data_pep import (
-        HINTS_PEP_META)
-
-    # Assert that various "TypeVar"-centric types are correctly detected.
-    for hint_pep_meta in HINTS_PEP_META:
-        assert is_hint_pep_typevars(hint_pep_meta.hint) is (
-            hint_pep_meta.is_typevars)
-
-    # Assert that various "TypeVar"-agnostic types are correctly detected.
-    for nonhint_pep in HINTS_NONPEP:
-        assert is_hint_pep_typevars(nonhint_pep) is False
-
 # ....................{ TESTS ~ typing                     }....................
-def test_is_hint_pep_typing() -> None:
+def test_is_hint_pep_typing(hints_pep_meta) -> None:
     '''
     Test the
     :func:`beartype._util.hint.pep.utilpeptest.is_hint_pep_typing` tester.
+
+    Parameters
+    ----------
+    hints_pep_meta : List[beartype_test.a00_unit.data.hint.util.data_hintmetacls.HintPepMetadata]
+        List of PEP-compliant type hint metadata describing sample PEP-compliant
+        type hints exercising edge cases in the :mod:`beartype` codebase.
     '''
 
     # Defer test-specific imports.
     from beartype._util.hint.pep.utilpeptest import (
         is_hint_pep_typing)
     from beartype_test.a00_unit.data.hint.data_hint import NOT_HINTS_PEP
-    from beartype_test.a00_unit.data.hint.pep.data_pep import (
-        HINTS_PEP_META)
 
     # Assert this tester accepts PEP-compliant type hints defined by the
     # "typing" module.
-    for hint_pep_meta in HINTS_PEP_META:
-        assert is_hint_pep_typing(hint_pep_meta.hint) is (
-            hint_pep_meta.is_typing)
+    for hint_pep_meta in hints_pep_meta:
+        # Localize this hint to simplify debugging.
+        hint = hint_pep_meta.hint
+        assert is_hint_pep_typing(hint) is hint_pep_meta.is_typing
 
     # Assert this tester rejects non-PEP-compliant type hints.
     for not_hint_pep in NOT_HINTS_PEP:
         assert is_hint_pep_typing(not_hint_pep) is False
 
 
-def test_is_hint_pep_type_typing() -> None:
+def test_is_hint_pep_type_typing(hints_pep_meta) -> None:
     '''
     Test the
     :func:`beartype._util.hint.pep.utilpeptest.is_hint_pep_type_typing`
     tester.
+
+    Parameters
+    ----------
+    hints_pep_meta : List[beartype_test.a00_unit.data.hint.util.data_hintmetacls.HintPepMetadata]
+        List of PEP-compliant type hint metadata describing sample PEP-compliant
+        type hints exercising edge cases in the :mod:`beartype` codebase.
     '''
 
     # Defer test-specific imports.
     from beartype._util.hint.pep.utilpeptest import (
         is_hint_pep_type_typing)
     from beartype_test.a00_unit.data.hint.data_hint import NOT_HINTS_PEP
-    from beartype_test.a00_unit.data.hint.pep.data_pep import (
-        HINTS_PEP_META)
 
     # Assert this tester accepts PEP-compliant type hints defined by the
     # "typing" module.
-    for hint_pep_meta in HINTS_PEP_META:
-        assert is_hint_pep_type_typing(hint_pep_meta.hint) is (
-            hint_pep_meta.is_type_typing)
+    for hint_pep_meta in hints_pep_meta:
+        # Localize this hint to simplify debugging.
+        hint = hint_pep_meta.hint
+        assert is_hint_pep_type_typing(hint) is hint_pep_meta.is_type_typing
 
     # Assert this tester rejects non-PEP-compliant type hints.
     for not_hint_pep in NOT_HINTS_PEP:
         assert is_hint_pep_type_typing(not_hint_pep) is False
 
 # ....................{ TESTS                              }....................
-def test_is_hint_pep() -> None:
+def test_is_hint_pep(hints_pep_meta, hints_nonpep_meta) -> None:
     '''
     Test the :func:`beartype._util.hint.pep.utilpeptest.is_hint_pep`
     tester.
+
+    Parameters
+    ----------
+    hints_pep_meta : List[beartype_test.a00_unit.data.hint.util.data_hintmetacls.HintPepMetadata]
+        List of PEP-compliant type hint metadata describing sample PEP-compliant
+        type hints exercising edge cases in the :mod:`beartype` codebase.
+    hints_nonpep_meta : Tuple[beartype_test.a00_unit.data.hint.util.data_hintmetacls.HintNonpepMetadata]
+        Tuple of PEP-noncompliant type hint metadata describing PEP-noncompliant
+        type hints exercising edge cases in the :mod:`beartype` codebase.
     '''
 
     # Defer test-specific imports.
     from beartype._util.hint.pep.utilpeptest import is_hint_pep
     from beartype_test.a00_unit.data.hint.data_hint import NOT_HINTS_PEP
-    from beartype_test.a00_unit.data.hint.nonpep.data_nonpep import (
-        HINTS_NONPEP_META)
-    from beartype_test.a00_unit.data.hint.pep.data_pep import HINTS_PEP_META
 
     # Assert this tester accepts PEP-compliant type hints.
-    for hint_pep_meta in HINTS_PEP_META:
+    for hint_pep_meta in hints_pep_meta:
         assert is_hint_pep(hint_pep_meta.hint) is True
 
     # Assert this tester rejects PEP-noncompliant type hints implemented by the
     # "typing" module as normal types indistinguishable from non-"typing" types
     # and thus effectively non-PEP-compliant for all practical intents.
-    for hint_nonpep_meta in HINTS_NONPEP_META:
-        # if is_hint_pep(hint_nonpep_meta.hint) is True:
-        #     from beartype._util.hint.pep.utilpepget import (
-        #         get_hint_pep_sign_or_none)
-        #     hint = hint_nonpep_meta.hint
-        #     print(f'hint {hint} sign: {get_hint_pep_sign_or_none(hint)}')
-
+    for hint_nonpep_meta in hints_nonpep_meta:
         assert is_hint_pep(hint_nonpep_meta.hint) is False
 
     # Assert this tester rejects non-PEP-compliant type hints.
@@ -128,27 +114,41 @@ def test_is_hint_pep() -> None:
         assert is_hint_pep(not_hint_pep) is False
 
 
-def test_is_hint_pep_args() -> None:
+def test_is_hint_pep_subbed(hints_pep_meta, hints_nonpep_meta) -> None:
     '''
-    Test the
-    :func:`beartype._util.hint.pep.utilpeptest.is_hint_pep_args`
+    Test the :func:`beartype._util.hint.pep.utilpeptest.is_hint_pep_subbed`
     tester.
+
+    Parameters
+    ----------
+    hints_pep_meta : List[beartype_test.a00_unit.data.hint.util.data_hintmetacls.HintPepMetadata]
+        List of PEP-compliant type hint metadata describing sample PEP-compliant
+        type hints exercising edge cases in the :mod:`beartype` codebase.
+    hints_nonpep_meta : Tuple[beartype_test.a00_unit.data.hint.util.data_hintmetacls.HintNonpepMetadata]
+        Tuple of PEP-noncompliant type hint metadata describing PEP-noncompliant
+        type hints exercising edge cases in the :mod:`beartype` codebase.
     '''
 
     # Defer test-specific imports.
-    from beartype._util.hint.pep.utilpeptest import is_hint_pep_args
+    from beartype._util.hint.pep.utilpeptest import is_hint_pep_subbed
     from beartype_test.a00_unit.data.hint.data_hint import NOT_HINTS_PEP
-    from beartype_test.a00_unit.data.hint.pep.data_pep import (
-        HINTS_PEP_META)
 
-    # Assert this tester accepts PEP-compliant subscripted type hints.
-    for hint_pep_meta in HINTS_PEP_META:
-        assert is_hint_pep_args(hint_pep_meta.hint) is (
+    # Assert this tester:
+    # * Accepts all subscripted PEP-compliant type hints.
+    # * Rejects all unsubscripted PEP-compliant type hints.
+    for hint_pep_meta in hints_pep_meta:
+        assert is_hint_pep_subbed(hint_pep_meta.hint) is (
             hint_pep_meta.is_args)
 
+    # Assert this tester rejects PEP-noncompliant type hints implemented by the
+    # "typing" module as normal types indistinguishable from non-"typing" types
+    # and thus effectively non-PEP-compliant for all practical intents.
+    for hint_nonpep_meta in hints_nonpep_meta:
+        assert is_hint_pep_subbed(hint_nonpep_meta.hint) is False
+
     # Assert this tester rejects non-PEP-compliant type hints.
     for not_hint_pep in NOT_HINTS_PEP:
-        assert is_hint_pep_args(not_hint_pep) is False
+        assert is_hint_pep_subbed(not_hint_pep) is False
 
 
 #FIXME: Implement us up, please.
@@ -171,7 +171,7 @@ def test_is_hint_pep_args() -> None:
 #         # True only if we expect this hint to be non-self-cached, including.
 #         is_hint_pep_uncached_expected = (
 #             # If th
-#             hint_pep_meta.is_pep585_builtin or
+#             hint_pep_meta.is_pep585_builtin_subbed or
 #             (
 #                 IS_PYTHON_AT_LEAST_3_9 and
 #                 hint_pep_meta
@@ -191,24 +191,30 @@ def test_is_hint_pep_args() -> None:
 #         assert is_hint_pep_uncached(not_hint_pep) is True
 
 # ....................{ TESTS ~ supported                  }....................
-def test_is_hint_pep_supported() -> None:
+def test_is_hint_pep_supported(hints_pep_meta) -> None:
     '''
     Test the
     :func:`beartype._util.hint.pep.utilpeptest.is_hint_pep_supported`
     tester.
+
+    Parameters
+    ----------
+    hints_pep_meta : List[beartype_test.a00_unit.data.hint.util.data_hintmetacls.HintPepMetadata]
+        List of PEP-compliant type hint metadata describing sample PEP-compliant
+        type hints exercising edge cases in the :mod:`beartype` codebase.
     '''
 
     # Defer test-specific imports.
     from beartype._util.hint.pep.utilpeptest import is_hint_pep_supported
     from beartype_test.a00_unit.data.hint.data_hint import (
-        NOT_HINTS_UNHASHABLE, NOT_HINTS_PEP)
-    from beartype_test.a00_unit.data.hint.pep.data_pep import (
-        HINTS_PEP_META)
+        NOT_HINTS_PEP,
+        NOT_HINTS_UNHASHABLE,
+    )
 
     # Assert this tester:
     # * Accepts supported PEP-compliant type hints.
     # * Rejects unsupported PEP-compliant type hints.
-    for hint_pep_meta in HINTS_PEP_META:
+    for hint_pep_meta in hints_pep_meta:
         assert is_hint_pep_supported(hint_pep_meta.hint) is (
             hint_pep_meta.is_supported)
 
@@ -221,11 +227,17 @@ def test_is_hint_pep_supported() -> None:
         assert is_hint_pep_supported(non_hint_unhashable) is False
 
 
-def test_die_if_hint_pep_unsupported() -> None:
+def test_die_if_hint_pep_unsupported(hints_pep_meta) -> None:
     '''
     Test the
     :func:`beartype._util.hint.pep.utilpeptest.die_if_hint_pep_unsupported`
     validator.
+
+    Parameters
+    ----------
+    hints_pep_meta : List[beartype_test.a00_unit.data.hint.util.data_hintmetacls.HintPepMetadata]
+        List of PEP-compliant type hint metadata describing sample PEP-compliant
+        type hints exercising edge cases in the :mod:`beartype` codebase.
     '''
 
     # Defer test-specific imports.
@@ -237,11 +249,10 @@ def test_die_if_hint_pep_unsupported() -> None:
         die_if_hint_pep_unsupported)
     from beartype_test.a00_unit.data.hint.data_hint import (
         NOT_HINTS_UNHASHABLE, NOT_HINTS_PEP)
-    from beartype_test.a00_unit.data.hint.pep.data_pep import (
-        HINTS_PEP_META)
+    from pytest import raises
 
     # Assert this validator...
-    for hint_pep_meta in HINTS_PEP_META:
+    for hint_pep_meta in hints_pep_meta:
         # Accepts supported PEP-compliant type hints.
         if hint_pep_meta.is_supported:
             die_if_hint_pep_unsupported(hint_pep_meta.hint)
